==> jc-1.4.0.tar.gz: soot/util/SharedBitSetCache.h <==
// public final class soot.util.SharedBitSetCache

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6f2f8692e0438b1e soot_util_SharedBitSetCache

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_SharedBitSetCache_H_
#define _JC_soot_util_SharedBitSetCache_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_util_BitVector$object;
struct _jc_soot_util_SharedBitSetCache$object;

// Typedefs
typedef struct _jc_soot_util_SharedBitSetCache$sub_refs	_jc_soot_util_SharedBitSetCache$sub_refs;
typedef struct _jc_soot_util_SharedBitSetCache$sub_nonrefs	_jc_soot_util_SharedBitSetCache$sub_nonrefs;
typedef struct _jc_soot_util_SharedBitSetCache$refs	_jc_soot_util_SharedBitSetCache$refs;
typedef struct _jc_soot_util_SharedBitSetCache$nonrefs	_jc_soot_util_SharedBitSetCache$nonrefs;
typedef struct _jc_soot_util_SharedBitSetCache$object	_jc_soot_util_SharedBitSetCache$object;

typedef struct _jc_soot_util_SharedBitSetCache$fields_struct	_jc_soot_util_SharedBitSetCache$fields_struct;
typedef const struct _jc_soot_util_SharedBitSetCache$vmethods	_jc_soot_util_SharedBitSetCache$vmethods;
typedef const struct _jc_soot_util_SharedBitSetCache$vtable	_jc_soot_util_SharedBitSetCache$vtable;
typedef const struct _jc_soot_util_SharedBitSetCache$vtype	_jc_soot_util_SharedBitSetCache$vtype;

// Class fields structure
struct _jc_soot_util_SharedBitSetCache$fields_struct {
	jint	size;
};
extern _jc_soot_util_SharedBitSetCache$fields_struct _jc_soot_util_SharedBitSetCache$class_fields;

// Constructors
extern void _jc_soot_util_SharedBitSetCache$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_util_SharedBitSetCache$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern struct _jc_soot_util_BitVector$object *_jc_soot_util_SharedBitSetCache$method$canonicalize$804c8827df472082(_jc_env *, struct _jc_soot_util_SharedBitSetCache$object *, struct _jc_soot_util_BitVector$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_util_SharedBitSetCache$method_info$canonicalize$804c8827df472082;

// Static methods
extern struct _jc_soot_util_SharedBitSetCache$object *_jc_soot_util_SharedBitSetCache$method$v$dd76b257dec12ad2(_jc_env *);

// Virtual methods structure
struct _jc_soot_util_SharedBitSetCache$vmethods {
	struct _jc_soot_util_BitVector$object	*(*canonicalize$804c8827df472082)(_jc_env *, struct _jc_soot_util_SharedBitSetCache$object *, struct _jc_soot_util_BitVector$object *);
};

// Vtable
struct _jc_soot_util_SharedBitSetCache$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_SharedBitSetCache$vmethods	soot_util_SharedBitSetCache;
};

// Vtype
struct _jc_soot_util_SharedBitSetCache$vtype {
	_jc_type			type;
	_jc_soot_util_SharedBitSetCache$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_SharedBitSetCache$sub_refs {
	_jc_object_array	*cache;
	_jc_object_array	*orAndAndNotCache;
};

// Reference instance fields (object)
struct _jc_soot_util_SharedBitSetCache$refs {
    _jc_soot_util_SharedBitSetCache$sub_refs	soot_util_SharedBitSetCache;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_SharedBitSetCache$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_SharedBitSetCache$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_SharedBitSetCache$sub_nonrefs	soot_util_SharedBitSetCache;
};

// Object instance structure
struct _jc_soot_util_SharedBitSetCache$object {
	_jc_soot_util_SharedBitSetCache$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_SharedBitSetCache$vtype	*vtype;
	_jc_soot_util_SharedBitSetCache$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_SharedBitSetCache$vtype _jc_soot_util_SharedBitSetCache$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_SharedBitSetCache, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_SharedBitSetCache$class_object;

#endif	/* _JC_soot_util_SharedBitSetCache_H_ */

==> jc-1.4.6.tar.gz: soot/util/SharedBitSetCache.h <==
// public final class soot.util.SharedBitSetCache

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6f2f8692e0438b1e soot_util_SharedBitSetCache

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_SharedBitSetCache_H_
#define _JC_soot_util_SharedBitSetCache_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_util_BitVector$object;
struct _jc_soot_util_SharedBitSetCache$object;

// Typedefs
typedef struct _jc_soot_util_SharedBitSetCache$sub_refs	_jc_soot_util_SharedBitSetCache$sub_refs;
typedef struct _jc_soot_util_SharedBitSetCache$sub_nonrefs	_jc_soot_util_SharedBitSetCache$sub_nonrefs;
typedef struct _jc_soot_util_SharedBitSetCache$refs	_jc_soot_util_SharedBitSetCache$refs;
typedef struct _jc_soot_util_SharedBitSetCache$nonrefs	_jc_soot_util_SharedBitSetCache$nonrefs;
typedef struct _jc_soot_util_SharedBitSetCache$object	_jc_soot_util_SharedBitSetCache$object;

typedef struct _jc_soot_util_SharedBitSetCache$fields_struct	_jc_soot_util_SharedBitSetCache$fields_struct;
typedef const struct _jc_soot_util_SharedBitSetCache$vmethods	_jc_soot_util_SharedBitSetCache$vmethods;
typedef const struct _jc_soot_util_SharedBitSetCache$vtable	_jc_soot_util_SharedBitSetCache$vtable;
typedef const struct _jc_soot_util_SharedBitSetCache$vtype	_jc_soot_util_SharedBitSetCache$vtype;

// Class fields structure
struct _jc_soot_util_SharedBitSetCache$fields_struct {
	jint	size;
};
extern _jc_soot_util_SharedBitSetCache$fields_struct _jc_soot_util_SharedBitSetCache$class_fields;

// Constructors
extern void _jc_soot_util_SharedBitSetCache$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_util_SharedBitSetCache$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_util_BitVector$object *_jc_soot_util_SharedBitSetCache$method$canonicalize$804c8827df472082(_jc_env *, struct _jc_soot_util_SharedBitSetCache$object *, struct _jc_soot_util_BitVector$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_util_SharedBitSetCache$method_info$canonicalize$804c8827df472082;

// Static methods
extern struct _jc_soot_util_SharedBitSetCache$object *_jc_soot_util_SharedBitSetCache$method$v$dd76b257dec12ad2(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_util_SharedBitSetCache$vmethods {
	struct _jc_soot_util_BitVector$object	*(*canonicalize$804c8827df472082)(_jc_env *, struct _jc_soot_util_SharedBitSetCache$object *, struct _jc_soot_util_BitVector$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_util_SharedBitSetCache$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_SharedBitSetCache$vmethods	soot_util_SharedBitSetCache;
};

// Vtype
struct _jc_soot_util_SharedBitSetCache$vtype {
	_jc_type			type;
	_jc_soot_util_SharedBitSetCache$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_SharedBitSetCache$sub_refs {
	_jc_object_array	*cache;
	_jc_object_array	*orAndAndNotCache;
};

// Reference instance fields (object)
struct _jc_soot_util_SharedBitSetCache$refs {
    _jc_soot_util_SharedBitSetCache$sub_refs	soot_util_SharedBitSetCache;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_SharedBitSetCache$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_SharedBitSetCache$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_SharedBitSetCache$sub_nonrefs	soot_util_SharedBitSetCache;
};

// Object instance structure
struct _jc_soot_util_SharedBitSetCache$object {
	_jc_soot_util_SharedBitSetCache$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_SharedBitSetCache$vtype	*vtype;
	_jc_soot_util_SharedBitSetCache$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_SharedBitSetCache$vtype _jc_soot_util_SharedBitSetCache$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_SharedBitSetCache, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_SharedBitSetCache$class_object;

#endif	/* _JC_soot_util_SharedBitSetCache_H_ */
